isbn

package module
v0.0.0-...-aa3ad5d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 5, 2024 License: MIT Imports: 2 Imported by: 0

README

isbn

The isbn package inspects and verifies International Standard Book Numbers (ISBNs) according to the ISO standard.

[!WARNING] This package will in its current version validate British Standard Book Numbers (SBN), ISBN-10 and ISBN-13 only according to their structure.

As of now it will not validate if an ISBN is actually contained in an ISBN range.

Furthermore it will not handle other but similar identifiers like EAN-13 in general, Digital Object Identifier (DOI), ISBN-A, International Standard Music Number (ISMN), International Standard Serial Number (ISSN) or International Standard Link Identifier (ISLI).

Contributions

Issues and PRs are welcome.

License

The package is licensed under MIT license.

Install
go get github.com/skowalak/isbn
Documentation

Go Reference

Documentation

Overview

The isbn package inspects and verifies International Standard Book Numbers (ISBN) according to the ISO standard

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ISBN10

func ISBN10(s string) (string, error)

ISBN10 takes a valid ISBN-13 or ISBN-10 and returns the corresponding ISBN-10 which is ten runes and three hyphens long.

func ISBN13

func ISBN13(s string) (string, error)

ISBN13 takes a valid ISBN-13 or ISBN-10 and returns the corresponding ISBN-13 which is thirteen runes and four hyphens long.

func SBN

func SBN(s string) (string, error)

SBN takes a valid ISBN-13 or ISBN-10 and returns the corresponding British Standard Book Number (SBN) which is nine digits and two hyphens long. An SBN only exists, if the ISBN group element is zero.

Types

This section is empty.

Jump to